@@ -12,17 +12,16 @@
 #include "types.h"
 
 struct zathura_page_s {
-  double height; /**< Page height */
-  double width; /**< Page width */
-  unsigned int index; /**< Page number */
-  void* data; /**< Custom data */
-  bool visible; /**< Page is visible */
-  zathura_document_t* document; /**< Document */
+  zathura_document_t* document; /**< Parent document */
+  void* data;                   /**< Custom data */
+  char* label;                  /**< Page label */
+  double height;                /**< Page height */
+  double width;                 /**< Page width */
+  unsigned int index;           /**< Page number */
+  bool visible;                 /**< Page is visible */
 };
 
-zathura_page_t*
-zathura_page_new(zathura_document_t* document, unsigned int index, zathura_error_t* error)
-{
+zathura_page_t* zathura_page_new(zathura_document_t* document, unsigned int index, zathura_error_t* error) {
   if (document == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -44,16 +43,9 @@ zathura_page_new(zathura_document_t* document, unsigned int index, zathura_error
   page->document = document;
 
   /* init plugin */
-  zathura_plugin_t* plugin = zathura_document_get_plugin(document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
 
-  if (functions->page_init == NULL) {
-    if (error != NULL) {
-      *error = ZATHURA_ERROR_NOT_IMPLEMENTED;
-    }
-    goto error_free;
-  }
-
   zathura_error_t ret = functions->page_init(page);
   if (ret != ZATHURA_ERROR_OK) {
     if (error != NULL) {
@@ -62,6 +54,17 @@ zathura_page_new(zathura_document_t* document, unsigned int index, zathura_error
     goto error_free;
   }
 
+  /* get label if there is one */
+  if (functions->page_get_label != NULL) {
+    ret = functions->page_get_label(page, page->data, &page->label);
+    if (ret != ZATHURA_ERROR_OK) {
+      if (error != NULL) {
+        *error = ret;
+      }
+      goto error_free;
+    }
+  }
+
   return page;
 
 error_free:
@@ -75,9 +78,7 @@ error_ret:
   return NULL;
 }
 
-zathura_error_t
-zathura_page_free(zathura_page_t* page)
-{
+zathura_error_t zathura_page_free(zathura_page_t* page) {
   if (page == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
@@ -87,22 +88,18 @@ zathura_page_free(zathura_page_t* page)
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
-  if (functions->page_clear == NULL) {
-    return ZATHURA_ERROR_NOT_IMPLEMENTED;
-  }
 
   zathura_error_t error = functions->page_clear(page, page->data);
 
+  g_free(page->label);
   g_free(page);
 
   return error;
 }
 
-zathura_document_t*
-zathura_page_get_document(zathura_page_t* page)
-{
+zathura_document_t* zathura_page_get_document(zathura_page_t* page) {
   if (page == NULL) {
     return NULL;
   }
@@ -110,9 +107,7 @@ zathura_page_get_document(zathura_page_t* page)
   return page->document;
 }
 
-unsigned int
-zathura_page_get_index(zathura_page_t* page)
-{
+unsigned int zathura_page_get_index(zathura_page_t* page) {
   if (page == NULL) {
     return 0;
   }
@@ -120,9 +115,7 @@ zathura_page_get_index(zathura_page_t* page)
   return page->index;
 }
 
-double
-zathura_page_get_width(zathura_page_t* page)
-{
+double zathura_page_get_width(zathura_page_t* page) {
   if (page == NULL) {
     return -1;
   }
@@ -130,9 +123,7 @@ zathura_page_get_width(zathura_page_t* page)
   return page->width;
 }
 
-void
-zathura_page_set_width(zathura_page_t* page, double width)
-{
+void zathura_page_set_width(zathura_page_t* page, double width) {
   if (page == NULL) {
     return;
   }
@@ -140,9 +131,7 @@ zathura_page_set_width(zathura_page_t* page, double width)
   page->width = width;
 }
 
-double
-zathura_page_get_height(zathura_page_t* page)
-{
+double zathura_page_get_height(zathura_page_t* page) {
   if (page == NULL) {
     return -1;
   }
@@ -150,9 +139,7 @@ zathura_page_get_height(zathura_page_t* page)
   return page->height;
 }
 
-void
-zathura_page_set_height(zathura_page_t* page, double height)
-{
+void zathura_page_set_height(zathura_page_t* page, double height) {
   if (page == NULL) {
     return;
   }
@@ -160,9 +147,7 @@ zathura_page_set_height(zathura_page_t* page, double height)
   page->height = height;
 }
 
-bool
-zathura_page_get_visibility(zathura_page_t* page)
-{
+bool zathura_page_get_visibility(zathura_page_t* page) {
   if (page == NULL) {
     return false;
   }
@@ -170,9 +155,7 @@ zathura_page_get_visibility(zathura_page_t* page)
   return page->visible;
 }
 
-void
-zathura_page_set_visibility(zathura_page_t* page, bool visibility)
-{
+void zathura_page_set_visibility(zathura_page_t* page, bool visibility) {
   if (page == NULL) {
     return;
   }
@@ -180,9 +163,7 @@ zathura_page_set_visibility(zathura_page_t* page, bool visibility)
   page->visible = visibility;
 }
 
-void*
-zathura_page_get_data(zathura_page_t* page)
-{
+void* zathura_page_get_data(zathura_page_t* page) {
   if (page == NULL) {
     return NULL;
   }
@@ -190,9 +171,7 @@ zathura_page_get_data(zathura_page_t* page)
   return page->data;
 }
 
-void
-zathura_page_set_data(zathura_page_t* page, void* data)
-{
+void zathura_page_set_data(zathura_page_t* page, void* data) {
   if (page == NULL) {
     return;
   }
@@ -200,9 +179,7 @@ zathura_page_set_data(zathura_page_t* page, void* data)
   page->data = data;
 }
 
-girara_list_t*
-zathura_page_search_text(zathura_page_t* page, const char* text, zathura_error_t* error)
-{
+girara_list_t* zathura_page_search_text(zathura_page_t* page, const char* text, zathura_error_t* error) {
   if (page == NULL || page->document == NULL || text == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -210,7 +187,7 @@ zathura_page_search_text(zathura_page_t* page, const char* text, zathura_error_t
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_search_text == NULL) {
     if (error != NULL) {
@@ -222,17 +199,15 @@ zathura_page_search_text(zathura_page_t* page, const char* text, zathura_error_t
   return functions->page_search_text(page, page->data, text, error);
 }
 
-girara_list_t*
-zathura_page_links_get(zathura_page_t* page, zathura_error_t* error)
-{
-  if (page == NULL || page->document == NULL ) {
+girara_list_t* zathura_page_links_get(zathura_page_t* page, zathura_error_t* error) {
+  if (page == NULL || page->document == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_links_get == NULL) {
     if (error != NULL) {
@@ -244,23 +219,19 @@ zathura_page_links_get(zathura_page_t* page, zathura_error_t* error)
   return functions->page_links_get(page, page->data, error);
 }
 
-zathura_error_t
-zathura_page_links_free(girara_list_t* UNUSED(list))
-{
+zathura_error_t zathura_page_links_free(girara_list_t* UNUSED(list)) {
   return false;
 }
 
-girara_list_t*
-zathura_page_form_fields_get(zathura_page_t* page, zathura_error_t* error)
-{
-  if (page == NULL || page->document == NULL ) {
+girara_list_t* zathura_page_form_fields_get(zathura_page_t* page, zathura_error_t* error) {
+  if (page == NULL || page->document == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_form_fields_get == NULL) {
     if (error != NULL) {
@@ -272,23 +243,19 @@ zathura_page_form_fields_get(zathura_page_t* page, zathura_error_t* error)
   return functions->page_form_fields_get(page, page->data, error);
 }
 
-zathura_error_t
-zathura_page_form_fields_free(girara_list_t* UNUSED(list))
-{
+zathura_error_t zathura_page_form_fields_free(girara_list_t* UNUSED(list)) {
   return ZATHURA_ERROR_NOT_IMPLEMENTED;
 }
 
-girara_list_t*
-zathura_page_images_get(zathura_page_t* page, zathura_error_t* error)
-{
-  if (page == NULL || page->document == NULL ) {
+girara_list_t* zathura_page_images_get(zathura_page_t* page, zathura_error_t* error) {
+  if (page == NULL || page->document == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_images_get == NULL) {
     if (error != NULL) {
@@ -300,17 +267,15 @@ zathura_page_images_get(zathura_page_t* page, zathura_error_t* error)
   return functions->page_images_get(page, page->data, error);
 }
 
-cairo_surface_t*
-zathura_page_image_get_cairo(zathura_page_t* page, zathura_image_t* image, zathura_error_t* error)
-{
-  if (page == NULL || page->document == NULL  || image == NULL) {
+cairo_surface_t* zathura_page_image_get_cairo(zathura_page_t* page, zathura_image_t* image, zathura_error_t* error) {
+  if (page == NULL || page->document == NULL || image == NULL) {
     if (error != NULL) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_image_get_cairo == NULL) {
     if (error != NULL) {
@@ -322,17 +287,15 @@ zathura_page_image_get_cairo(zathura_page_t* page, zathura_image_t* image, zathu
   return functions->page_image_get_cairo(page, page->data, image, error);
 }
 
-char*
-zathura_page_get_text(zathura_page_t* page, zathura_rectangle_t rectangle, zathura_error_t* error)
-{
-  if (page == NULL || page->document == NULL ) {
+char* zathura_page_get_text(zathura_page_t* page, zathura_rectangle_t rectangle, zathura_error_t* error) {
+  if (page == NULL || page->document == NULL) {
     if (error) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_get_text == NULL) {
     if (error) {
@@ -344,17 +307,15 @@ zathura_page_get_text(zathura_page_t* page, zathura_rectangle_t rectangle, zathu
   return functions->page_get_text(page, page->data, rectangle, error);
 }
 
-girara_list_t*
-zathura_page_get_selection(zathura_page_t* page, zathura_rectangle_t rectangle, zathura_error_t* error)
-{
-  if (page == NULL || page->document == NULL ) {
+girara_list_t* zathura_page_get_selection(zathura_page_t* page, zathura_rectangle_t rectangle, zathura_error_t* error) {
+  if (page == NULL || page->document == NULL) {
     if (error) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
     }
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_get_selection == NULL) {
     if (error) {
@@ -366,25 +327,18 @@ zathura_page_get_selection(zathura_page_t* page, zathura_rectangle_t rectangle,
   return functions->page_get_selection(page, page->data, rectangle, error);
 }
 
-zathura_error_t
-zathura_page_render(zathura_page_t* page, cairo_t* cairo, bool printing)
-{
-  if (page == NULL  || page->document == NULL || cairo == NULL) {
+zathura_error_t zathura_page_render(zathura_page_t* page, cairo_t* cairo, bool printing) {
+  if (page == NULL || page->document == NULL || cairo == NULL) {
     return ZATHURA_ERROR_INVALID_ARGUMENTS;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
-  if (functions->page_render_cairo == NULL) {
-    return ZATHURA_ERROR_NOT_IMPLEMENTED;
-  }
 
   return functions->page_render_cairo(page, page->data, cairo, printing);
 }
 
-char*
-zathura_page_get_label(zathura_page_t* page, zathura_error_t* error)
-{
+const char* zathura_page_get_label(zathura_page_t* page, zathura_error_t* error) {
   if (page == NULL || page->document == NULL) {
     if (error) {
       *error = ZATHURA_ERROR_INVALID_ARGUMENTS;
@@ -392,25 +346,7 @@ zathura_page_get_label(zathura_page_t* page, zathura_error_t* error)
     return NULL;
   }
 
-  zathura_plugin_t* plugin = zathura_document_get_plugin(page->document);
-  const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
-  if (functions->page_get_label == NULL) {
-    if (error) {
-      *error = ZATHURA_ERROR_NOT_IMPLEMENTED;
-    }
-    return NULL;
-  }
-
-  char* ret = NULL;
-  zathura_error_t e = functions->page_get_label(page, page->data, &ret);
-  if (e != ZATHURA_ERROR_OK) {
-    if (error) {
-      *error = e;
-    }
-    return NULL;
-  }
-
-  return ret;
+  return page->label;
 }
 
 girara_list_t* zathura_page_get_signatures(zathura_page_t* page, zathura_error_t* error) {
@@ -421,7 +357,7 @@ girara_list_t* zathura_page_get_signatures(zathura_page_t* page, zathura_error_t
     return NULL;
   }
 
-  zathura_plugin_t* plugin                    = zathura_document_get_plugin(page->document);
+  const zathura_plugin_t* plugin              = zathura_document_get_plugin(page->document);
   const zathura_plugin_functions_t* functions = zathura_plugin_get_functions(plugin);
   if (functions->page_get_signatures == NULL) {
     if (error) {
