@@ -20,9 +20,7 @@
 #include "plugin.h"
 #include "content-type.h"
 
-double
-zathura_correct_zoom_value(girara_session_t* session, const double zoom)
-{
+double zathura_correct_zoom_value(girara_session_t* session, const double zoom) {
   if (session == NULL) {
     return zoom;
   }
@@ -45,9 +43,7 @@ zathura_correct_zoom_value(girara_session_t* session, const double zoom)
   }
 }
 
-bool
-file_valid_extension(zathura_t* zathura, const char* path)
-{
+bool file_valid_extension(zathura_t* zathura, const char* path) {
   if (zathura == NULL || path == NULL || zathura->plugins.manager == NULL) {
     return false;
   }
@@ -57,20 +53,19 @@ file_valid_extension(zathura_t* zathura, const char* path)
     return false;
   }
 
-  zathura_plugin_t* plugin = zathura_plugin_manager_get_plugin(zathura->plugins.manager, content_type);
+  const zathura_plugin_t* plugin = zathura_plugin_manager_get_plugin(zathura->plugins.manager, content_type);
   g_free(content_type);
 
-  return plugin == NULL;
+  return plugin != NULL;
 }
 
-static void
-index_element_free(void* data, GObject* UNUSED(object))
-{
+static void index_element_free(void* data, GObject* UNUSED(object)) {
   zathura_index_element_t* element = data;
   zathura_index_element_free(element);
 }
 
-void document_index_build(GtkTreeModel* model, GtkTreeIter* parent, girara_tree_node_t* tree) {
+void document_index_build(girara_session_t* session, GtkTreeModel* model, GtkTreeIter* parent,
+                          girara_tree_node_t* tree) {
   girara_list_t* list = girara_node_get_children(tree);
 
   for (size_t idx = 0; idx != girara_list_size(list); ++idx) {
@@ -79,9 +74,20 @@ void document_index_build(GtkTreeModel* model, GtkTreeIter* parent, girara_tree_
     zathura_link_type_t type               = zathura_link_get_type(index_element->link);
     zathura_link_target_t target           = zathura_link_get_target(index_element->link);
 
-    gchar* description = NULL;
+    gchar* description  = NULL;
+    gchar* description2 = NULL;
+
     if (type == ZATHURA_LINK_GOTO_DEST) {
-      description = g_strdup_printf("Page %d", target.page_number + 1);
+      zathura_t* zathura   = session->global.data;
+      zathura_page_t* page = zathura_document_get_page(zathura->document, target.page_number);
+      const char* label    = zathura_page_get_label(page, NULL);
+
+      if (label != NULL) {
+        description  = g_strdup_printf("Page %s", label);
+        description2 = g_strdup_printf("(%d)", target.page_number + 1);
+      } else {
+        description = g_strdup_printf("Page %d", target.page_number + 1);
+      }
     } else {
       description = g_strdup(target.value);
     }
@@ -89,17 +95,51 @@ void document_index_build(GtkTreeModel* model, GtkTreeIter* parent, girara_tree_
     GtkTreeIter tree_iter;
     gtk_tree_store_append(GTK_TREE_STORE(model), &tree_iter, parent);
     gchar* markup = g_markup_escape_text(index_element->title, -1);
-    gtk_tree_store_set(GTK_TREE_STORE(model), &tree_iter, 0, markup, 1, description, 2, index_element, -1);
+    gtk_tree_store_set(GTK_TREE_STORE(model), &tree_iter, 0, markup, 1, description, 2, description2, 3, index_element,
+                       -1);
     g_free(markup);
-    g_object_weak_ref(G_OBJECT(model), index_element_free, index_element);
     g_free(description);
+    g_free(description2);
+    g_object_weak_ref(G_OBJECT(model), index_element_free, index_element);
 
     if (girara_node_get_num_children(node) > 0) {
-      document_index_build(model, &tree_iter, node);
+      document_index_build(session, model, &tree_iter, node);
     }
   }
 }
 
+typedef struct {
+  GtkTreeIter current_iter;
+  unsigned int current_page;
+} SearchData;
+
+static gboolean search_current_index(GtkTreeModel* model, GtkTreePath* UNUSED(path), GtkTreeIter* iter, gpointer data) {
+  SearchData* search_data = (SearchData*)data;
+  zathura_index_element_t* index_element;
+  gtk_tree_model_get(model, iter, 3, &index_element, -1);
+  zathura_link_target_t target = zathura_link_get_target(index_element->link);
+  if (target.page_number > search_data->current_page) {
+    return TRUE; // terminate foreach loop
+  }
+  search_data->current_iter = *iter;
+  return FALSE;
+}
+
+void index_scroll_to_current_page(zathura_t* zathura) {
+  GtkTreeView* tree_view = gtk_container_get_children(GTK_CONTAINER(zathura->ui.index))->data;
+  GtkTreeModel* model    = gtk_tree_view_get_model(tree_view);
+
+  SearchData search_data;
+  search_data.current_page = zathura_document_get_current_page_number(zathura->document);
+  gtk_tree_model_foreach(model, search_current_index, &search_data);
+
+  GtkTreePath* current_path = gtk_tree_model_get_path(model, &search_data.current_iter);
+  gtk_tree_view_expand_to_path(tree_view, current_path);
+  gtk_tree_view_set_cursor(tree_view, current_path, NULL, FALSE);
+  gtk_tree_view_scroll_to_cell(tree_view, current_path, NULL, TRUE, 0.5, 0.0);
+  gtk_tree_path_free(current_path);
+}
+
 zathura_rectangle_t rotate_rectangle(zathura_rectangle_t rectangle, unsigned int degree, double height, double width) {
   zathura_rectangle_t tmp;
   switch (degree) {
@@ -128,9 +168,7 @@ zathura_rectangle_t rotate_rectangle(zathura_rectangle_t rectangle, unsigned int
   return tmp;
 }
 
-zathura_rectangle_t
-recalc_rectangle(zathura_page_t* page, zathura_rectangle_t rectangle)
-{
+zathura_rectangle_t recalc_rectangle(zathura_page_t* page, zathura_rectangle_t rectangle) {
   if (page == NULL) {
     goto error_ret;
   }
@@ -144,7 +182,8 @@ recalc_rectangle(zathura_page_t* page, zathura_rectangle_t rectangle)
   double page_width  = zathura_page_get_width(page);
   double scale       = zathura_document_get_scale(document);
 
-  zathura_rectangle_t tmp = rotate_rectangle(rectangle, zathura_document_get_rotation(document), page_height, page_width);
+  zathura_rectangle_t tmp =
+      rotate_rectangle(rectangle, zathura_document_get_rotation(document), page_height, page_width);
   tmp.x1 *= scale;
   tmp.x2 *= scale;
   tmp.y1 *= scale;
@@ -156,9 +195,7 @@ error_ret:
   return rectangle;
 }
 
-GtkWidget*
-zathura_page_get_widget(zathura_t* zathura, zathura_page_t* page)
-{
+GtkWidget* zathura_page_get_widget(zathura_t* zathura, zathura_page_t* page) {
   if (zathura == NULL || page == NULL || zathura->pages == NULL) {
     return NULL;
   }
@@ -168,9 +205,7 @@ zathura_page_get_widget(zathura_t* zathura, zathura_page_t* page)
   return zathura->pages[page_number];
 }
 
-void
-document_draw_search_results(zathura_t* zathura, bool value)
-{
+void document_draw_search_results(zathura_t* zathura, bool value) {
   if (zathura == NULL || zathura->document == NULL || zathura->pages == NULL) {
     return;
   }
@@ -181,8 +216,8 @@ document_draw_search_results(zathura_t* zathura, bool value)
   }
 }
 
-char* zathura_get_version_string(zathura_t* zathura, bool markup) {
-  if (zathura == NULL) {
+char* zathura_get_version_string(const zathura_plugin_manager_t* plugin_manager, bool markup) {
+  if (plugin_manager == NULL) {
     return NULL;
   }
 
@@ -196,10 +231,10 @@ char* zathura_get_version_string(zathura_t* zathura, bool markup) {
       (markup == true) ? "\n<i>(plugin)</i> %s (%d.%d.%d) <i>(%s)</i>" : "\n(plugin) %s (%d.%d.%d) (%s)";
 
   /* plugin information */
-  girara_list_t* plugins = zathura_plugin_manager_get_plugins(zathura->plugins.manager);
+  girara_list_t* plugins = zathura_plugin_manager_get_plugins(plugin_manager);
   if (plugins != NULL) {
     for (size_t idx = 0; idx != girara_list_size(plugins); ++idx) {
-      zathura_plugin_t* plugin         = girara_list_nth(plugins, idx);
+      const zathura_plugin_t* plugin   = girara_list_nth(plugins, idx);
       const char* name                 = zathura_plugin_get_name(plugin);
       zathura_plugin_version_t version = zathura_plugin_get_version(plugin);
       g_string_append_printf(string, format, (name == NULL) ? "-" : name, version.major, version.minor, version.rev,
@@ -207,12 +242,14 @@ char* zathura_get_version_string(zathura_t* zathura, bool markup) {
     }
   }
 
+#if GLIB_CHECK_VERSION(2, 76, 0)
+  return g_string_free_and_steal(string);
+#else
   return g_string_free(string, FALSE);
+#endif
 }
 
-GdkAtom*
-get_selection(zathura_t* zathura)
-{
+GdkAtom* get_selection(zathura_t* zathura) {
   g_return_val_if_fail(zathura != NULL, NULL);
 
   char* value = NULL;
@@ -244,37 +281,120 @@ get_selection(zathura_t* zathura)
   return selection;
 }
 
-unsigned int
-find_first_page_column(const char* first_page_column_list,
-                       const unsigned int pages_per_row)
-{
-  /* sanity checks */
-  unsigned int first_page_column = 1;
-  g_return_val_if_fail(first_page_column_list != NULL,  first_page_column);
-  g_return_val_if_fail(*first_page_column_list != '\0', first_page_column);
-  g_return_val_if_fail(pages_per_row > 0,               first_page_column);
-
-  /* split settings list */
-  char** settings = g_strsplit(first_page_column_list, ":", pages_per_row + 1);
-  const size_t settings_size = g_strv_length(settings);
-
-  /* read setting value corresponding to the specified pages per row */
-  unsigned int index = pages_per_row - 1;
-  if (index < settings_size && *settings[index] != '\0') {
-    first_page_column = atoi(settings[index]);
-  } else if (*settings[settings_size - 1] != '\0') {
-    first_page_column = atoi(settings[settings_size - 1]);
+char* write_first_page_column_list(unsigned int* first_page_columns, unsigned int size) {
+  if (first_page_columns == NULL) {
+    return NULL;
   }
 
-  /* free buffers */
-  g_strfreev(settings);
+  GString* buffer = g_string_new(NULL);
+  for (unsigned int i = 0; i < size; i++) {
+    if (i != 0) {
+      g_string_append_printf(buffer, ":%u", first_page_columns[i]);
+    } else {
+      g_string_append_printf(buffer, "%u", first_page_columns[i]);
+    }
+  }
+
+#if GLIB_CHECK_VERSION(2, 76, 0)
+  return g_string_free_and_steal(buffer);
+#else
+  return g_string_free(buffer, FALSE);
+#endif
+}
+
+unsigned int* parse_first_page_column_list(const char* first_page_column_list, unsigned int* size) {
+  if (first_page_column_list == NULL || size == NULL) {
+    return NULL;
+  }
+
+  char** tokens       = g_strsplit(first_page_column_list, ":", 0);
+  unsigned int length = g_strv_length(tokens);
+
+  unsigned int* settings = g_malloc_n(length, sizeof(unsigned int));
+  for (unsigned int i = 0; i < length; i++) {
+    guint64 column = 1;
+
+    if (g_ascii_string_to_unsigned(tokens[i], 10, 1, i + 1, &column, NULL) == TRUE && column <= UINT_MAX) {
+      settings[i] = (unsigned int)column;
+    } else {
+      settings[i] = 1;
+    }
+  }
+
+  g_strfreev(tokens);
+
+  *size = length;
+  return settings;
+}
+
+unsigned int find_first_page_column(const char* first_page_column_list, const unsigned int pages_per_row) {
+  /* sanity checks */
+  unsigned int first_page_column = 1;
+  g_return_val_if_fail(first_page_column_list != NULL, first_page_column);
+  g_return_val_if_fail(pages_per_row > 0, first_page_column);
+
+  unsigned int size      = 0;
+  unsigned int* settings = parse_first_page_column_list(first_page_column_list, &size);
+
+  if (pages_per_row <= size) {
+    first_page_column = settings[pages_per_row - 1];
+  } else if (size > 0) {
+    first_page_column = settings[size - 1];
+  }
+
+  g_free(settings);
 
   return first_page_column;
 }
 
-bool
-parse_color(GdkRGBA* color, const char* str)
-{
+char* increment_first_page_column(const char* first_page_column_list, const unsigned int pages_per_row, int incr) {
+  /* sanity checks */
+  if (first_page_column_list == NULL) {
+    first_page_column_list = "";
+  }
+  /* This function is a no-op for 1 column layout */
+  if (pages_per_row <= 1) {
+    return g_strdup(first_page_column_list);
+  }
+
+  unsigned int size      = 0;
+  unsigned int* settings = parse_first_page_column_list(first_page_column_list, &size);
+
+  /* Lookup current setting. Signed value to avoid negative overflow when modifying it later. */
+  int column = 1;
+  if (pages_per_row <= size) {
+    column = settings[pages_per_row - 1];
+  } else if (size > 0) {
+    column = settings[size - 1];
+  }
+
+  /* increment and normalise to [1,pages_per_row]. */
+  column += incr;
+  column %= pages_per_row; /* range [-pages_per_row+1, pages_per_row-1] */
+  if (column <= 0)
+    column += pages_per_row; /* range [1, pages_per_row] */
+
+  /* Write back, creating the new cell if necessary. */
+  if (pages_per_row <= size) {
+    settings[pages_per_row - 1] = column;
+  } else {
+    /* extend settings array */
+    settings = g_realloc_n(settings, pages_per_row, sizeof(*settings));
+    for (unsigned int i = size; i < pages_per_row - 1; i++) {
+      /* The value of the last set cell is normally used for all largers pages_per_row,
+       * so duplicate it to the newly created cells. */
+      settings[i] = settings[size - 1];
+    }
+    settings[pages_per_row - 1] = column;
+    size                        = pages_per_row;
+  }
+
+  char* new_column_list = write_first_page_column_list(settings, size);
+  g_free(settings);
+  return new_column_list;
+}
+
+bool parse_color(GdkRGBA* color, const char* str) {
   if (gdk_rgba_parse(color, str) == FALSE) {
     girara_warning("Failed to parse color string '%s'.", str);
     return false;
@@ -282,18 +402,6 @@ parse_color(GdkRGBA* color, const char* str)
   return true;
 }
 
-bool
-running_under_wsl(void)
-{
-  bool result = false;
-  char* content = girara_file_read("/proc/version");
-  if (content != NULL && g_strstr_len(content, -1, "Microsoft")) {
-    result = true;
-  }
-  free(content);
-  return result;
-}
-
 typedef struct zathura_point_s {
   uintptr_t x;
   uintptr_t y;
