@@ -9,10 +9,9 @@
 
 #include "document.h"
 
-#define LENGTH(x) (sizeof(x)/sizeof((x)[0]))
+#define LENGTH(x) (sizeof(x) / sizeof((x)[0]))
 
-typedef struct page_offset_s
-{
+typedef struct page_offset_s {
   int x;
   int y;
 } page_offset_t;
@@ -31,11 +30,20 @@ bool file_valid_extension(zathura_t* zathura, const char* path);
  * Generates the document index based upon the list retrieved from the document
  * object.
  *
+ * @param session The session
  * @param model The tree model
  * @param parent The tree iterator parent
  * @param tree The Tree iterator
  */
-void document_index_build(GtkTreeModel* model, GtkTreeIter* parent, girara_tree_node_t* tree);
+void document_index_build(girara_session_t* session, GtkTreeModel* model, GtkTreeIter* parent,
+                          girara_tree_node_t* tree);
+
+/**
+ * Scrolls the document index to the current page
+ *
+ * @param zathura The zathura instance
+ */
+void index_scroll_to_current_page(zathura_t* zathura);
 
 /**
  * Rotate a rectangle by 0, 90, 180 or 270 degree
@@ -79,11 +87,11 @@ void document_draw_search_results(zathura_t* zathura, bool value);
 /**
  * Create zathura version string
  *
- * @param zathura The zathura instance
+ * @param plugin_manager The plugin manager
  * @param markup Enable markup
  * @return Version string
  */
-char* zathura_get_version_string(zathura_t* zathura, bool markup);
+char* zathura_get_version_string(const zathura_plugin_manager_t* plugin_manager, bool markup);
 
 /**
  * Get a pointer to the GdkAtom of the current clipboard.
@@ -104,8 +112,31 @@ GdkAtom* get_selection(zathura_t* zathura);
  *
  * @return The corrected zoom value
  */
-double zathura_correct_zoom_value(girara_session_t* session, const double
-    zoom);
+double zathura_correct_zoom_value(girara_session_t* session, const double zoom);
+
+/**
+ * Write a list of 'pages per row to first column' values as a colon separated string.
+ *
+ * For valid settings list, this is the inverse of parse_first_page_column_list.
+ *
+ * @param[in] first_page_columns The settings vector
+ * @param[in] size The size of the settings vector
+ *
+ * @return The new settings string
+ */
+char* write_first_page_column(unsigned int* first_page_columns, unsigned int size);
+
+/**
+ * Parse a 'pages per row to first column' settings list.
+ *
+ * For valid settings list, this is the inverse of write_first_page_column_list.
+ *
+ * @param[in] first_page_column_list The settings list
+ * @param[in] size A cell to return the size of the result, mandatory
+ *
+ * @return The values from the settings list as a new vector
+ */
+unsigned int* parse_first_page_column(const char* first_page_column_list, unsigned int* size);
 
 /**
  * Extracts the column the first page should be rendered in from the specified
@@ -116,8 +147,18 @@ double zathura_correct_zoom_value(girara_session_t* session, const double
  *
  * @return The column the first page should be rendered in
  */
-unsigned int find_first_page_column(const char* first_page_column_list,
-                                    const unsigned int pages_per_row);
+unsigned int find_first_page_column(const char* first_page_column_list, const unsigned int pages_per_row);
+
+/**
+ * Cycle the column the first page should be rendered in.
+ *
+ * @param[in] first_page_column_list The settings list
+ * @param[in] pages_per_row The current pages per row
+ * @param[in] incr The value added to the current first page column setting
+ *
+ * @return The new modified settings list
+ */
+char* increment_first_page_column(const char* first_page_column_list, const unsigned int pages_per_row, int incr);
 
 /**
  * Parse color string and print warning if color cannot be parsed.
@@ -129,13 +170,6 @@ unsigned int find_first_page_column(const char* first_page_column_list,
  */
 bool parse_color(GdkRGBA* color, const char* str);
 
-/**
- * Check if zathura is running under the Linux subsystem on Windows.
- *
- * @return true if running under WSL, false otherwise
- */
-bool running_under_wsl(void);
-
 /**
  * Flatten list of overlapping rectangles.
  *
